@@ -1,5 +1,15 @@
 from __future__ import print_function
 
+__all__ = [
+    "BaseJsonValidator",
+    "ItemsValidator",
+    "JsonSchema",
+    "JsonType",
+    "JsonValidator",
+    "TypeValidator",
+    "ValidationMessage",
+]
+
 from typing import Any, Dict, List, Optional, Set, Tuple
 
 from com.inductiveautomation.ignition.common import JsonPath
@@ -131,7 +141,7 @@ class JsonSchema(BaseJsonValidator):
         pass
 
     def getRefSchemaNode(self, ref=None):
-        # type: (AnyStr) -> JsonElement
+        # type: (Optional[AnyStr]) -> JsonElement
         pass
 
     def getSchemasForItems(self):
