@@ -1,16 +1,19 @@
+__all__ = ["PerspectiveModule"]
+
 from typing import Optional
 
 from com.inductiveautomation.ignition.common.gson import Gson, JsonObject
 from com.inductiveautomation.ignition.common.jsonschema import JsonSchema
 from com.inductiveautomation.ignition.common.util import LoggerEx
-from java.lang import Object, String
+from dev.thecesrom.helper.types import AnyStr
+from java.lang import Object
 from java.util.function import Consumer
 
 
 class PerspectiveModule(Object):
-    LOG_PREFIX = None  # type: String
+    LOG_PREFIX = None  # type: AnyStr
     META_SCHEMA = None  # type: JsonSchema
-    MODULE_ID = None  # type: String
+    MODULE_ID = None  # type: AnyStr
     SESSION_PROPS_SCHEMA = None  # type: JsonSchema
     VIEW_SCHEMA = None  # type: JsonSchema
 
@@ -36,5 +39,5 @@ class PerspectiveModule(Object):
 
     @staticmethod
     def getLogger(name):
-        # type: (String) -> LoggerEx
+        # type: (AnyStr) -> LoggerEx
         pass
