@@ -1,3 +1,5 @@
+__all__ = ["Binding", "DefaultBindableModel"]
+
 from typing import Any
 
 from java.lang import Object
@@ -10,6 +12,10 @@ class Binding(object):
 
 
 class DefaultBindableModel(Object):
+    def __init__(self):
+        # type: () -> None
+        super(DefaultBindableModel, self).__init__()
+
     def bind(self, toBind):
         # type: (Binding) -> None
         pass
