@@ -18,14 +18,15 @@ __all__ = [
 
 from typing import Any, Optional
 
+from dev.thecesrom.helper.types import AnyStr
 from java.awt.geom import Dimension2D, Point2D
-from java.lang import Object, String
+from java.lang import Object
 from java.util import EventObject
 
 
 class LayoutManager(object):
     def addLayoutComponent(self, name, comp):
-        # type: (String, Component) -> None
+        # type: (AnyStr, Component) -> None
         raise NotImplementedError
 
     def layoutContainer(self, parent):
@@ -58,7 +59,7 @@ class AWTEvent(EventObject):
         return self._id
 
     def paramString(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     def setSource(self, newSource):
@@ -69,6 +70,7 @@ class AWTEvent(EventObject):
 class Color(Object):
     def __init__(self, *args):
         # type: (*Any) -> None
+        super(Color, self).__init__()
         print(args)
 
 
@@ -98,7 +100,8 @@ class Dimension(Dimension2D):
 
     def __init__(self, *args):
         # type: (*Any) -> None
-        pass
+        super(Dimension, self).__init__()
+        print(args)
 
     def getHeight(self):
         # type: () -> float
@@ -137,7 +140,8 @@ class Point(Point2D):
 
     def __init__(self, *args):
         # type: (*Any) -> None
-        pass
+        super(Point, self).__init__()
+        print(args)
 
     def getLocation(self):
         # type: () -> Point
@@ -167,7 +171,7 @@ class Point(Point2D):
 class Toolkit(Object):
     def __init__(self):
         # type: () -> None
-        pass
+        super(Toolkit, self).__init__()
 
     def beep(self):
         # type: () -> None
@@ -182,7 +186,7 @@ class Toolkit(Object):
 class Window(Container):
     def __init__(self, *args):
         # type: (*Any) -> None
-        pass
+        super(Window, self).__init__()
 
 
 class Frame(Window):
@@ -206,10 +210,11 @@ class GridLayout(Object, LayoutManager):
         vgap=None,  # type: Optional[int]
     ):
         # type: (...) -> None
+        super(GridLayout, self).__init__()
         print(rows, cols, hgap, vgap)
 
     def addLayoutComponent(self, name, comp):
-        # type: (String, Component) -> None
+        # type: (AnyStr, Component) -> None
         pass
 
     def getColumns(self):
