@@ -9,6 +9,7 @@ __all__ = [
     "AutoCloseable",
     "CharSequence",
     "Class",
+    "Comparable",
     "Enum",
     "Exception",
     "IllegalArgumentException",
@@ -26,20 +27,25 @@ __all__ = [
 ]
 
 import __builtin__ as builtins
+import array
 import time
-from typing import Any, List, Optional, TypeVar, Union
+from typing import Any, List, Optional, Union
 
-String = Union[str, unicode]
-T = TypeVar("T")
-U = TypeVar("U")
+from dev.thecesrom.helper.types import AnyStr
+from java.lang.reflect import Type
 
 
 class Object(object):
-    """Class Object is the root of the class hierarchy. Every class has
-    Object as a superclass. All objects, including arrays, implement the
-    methods of this class.
+    """Class Object is the root of the class hierarchy.
+
+    Every class has Object as a superclass. All objects, including
+    arrays, implement the methods of this class.
     """
 
+    def __init__(self):
+        # type: () -> None
+        super(Object, self).__init__()
+
     def __cmp__(self, other):
         # type: (Object) -> bool
         return True
@@ -66,7 +72,7 @@ class Object(object):
 
     def hashCode(self):
         # type: () -> int
-        pass
+        return hash(self)
 
     def notify(self):
         # type: () -> None
@@ -77,7 +83,7 @@ class Object(object):
         pass
 
     def toString(self):
-        # type: () -> String
+        # type: () -> AnyStr
         return repr(self)
 
     def wait(self, timeoutMillis=0, nanos=0):
@@ -122,7 +128,13 @@ class CharSequence(object):
         raise NotImplementedError
 
     def toString(self):
-        # type: () -> String
+        # type: () -> AnyStr
+        raise NotImplementedError
+
+
+class Comparable(object):
+    def compareTo(self, o):
+        # type: (Any) -> int
         raise NotImplementedError
 
 
@@ -132,13 +144,17 @@ class Runnable(object):
         raise NotImplementedError
 
 
-class Class(Object):
+class Class(Object, Type):
     def asSubClass(self, clazz):
-        # type: (Class) -> U
+        # type: (Class) -> Any
         pass
 
     def cast(self, obj):
-        # type: (Object) -> T
+        # type: (Object) -> Any
+        pass
+
+    def getTypeName(self):
+        # type: () -> AnyStr
         pass
 
 
@@ -152,7 +168,7 @@ class Enum(Object):
         pass
 
     def name(self):
-        # type: () -> String
+        # type: () -> AnyStr
         pass
 
     def ordinal(self):
@@ -161,7 +177,7 @@ class Enum(Object):
 
     @staticmethod
     def valueOf(enumType, name):
-        # type: (Class, String) -> Enum
+        # type: (Class, AnyStr) -> Enum
         pass
 
 
@@ -194,7 +210,8 @@ class Number(Object):
 class StackTraceElement(Object):
     def __init__(self, *args):
         # type: (*Any) -> None
-        pass
+        super(StackTraceElement, self).__init__()
+        print(args)
 
     def getClassLoaderName(self):
         # type: () -> str
@@ -229,10 +246,207 @@ class StackTraceElement(Object):
         return True
 
 
+class String(unicode):
+    def __new__(cls, *args):
+        # type: (Any, *Any) -> Any
+        print(args)
+        return super(String, cls).__new__(cls, *args)
+
+    def __init__(self, *args):
+        # type: (*Any) -> None
+        super(String, self).__init__(*args)
+
+    def charAt(self, index):
+        # type: (int) -> unicode
+        pass
+
+    def chars(self):  # type: ignore[no-untyped-def]
+        pass
+
+    def codePointAt(self, index):
+        # type: (int) -> int
+        pass
+
+    def codePointBefore(self, index):
+        # type: (int) -> int
+        pass
+
+    def codePointCount(self, beginIndex, endIndex):
+        # type: (int, int) -> int
+        pass
+
+    def codePoints(self):  # type: ignore[no-untyped-def]
+        pass
+
+    @staticmethod
+    def compare(cs1, cs2):
+        # type: (CharSequence, CharSequence) -> int
+        pass
+
+    def compareTo(self, anotherString):
+        # type: (String) -> int
+        pass
+
+    def compareToIgnoreCase(self, arg):
+        # type: (String) -> int
+        pass
+
+    def concat(self, arg):
+        # type: (String) -> String
+        pass
+
+    def contains(self, arg):
+        # type: (String) -> bool
+        pass
+
+    def contentEquals(self, arg):
+        # type: (Union[CharSequence, StringBuffer]) -> bool
+        pass
+
+    @staticmethod
+    def copyValueOf(*args):
+        # type: (*Any) -> String
+        pass
+
+    def endsWith(self, suffix):
+        # type: (String) -> bool
+        return self.endswith(suffix)
+
+    def equals(self, anObject):
+        # type: (Object) -> bool
+        pass
+
+    def equalsIgnoreCase(self, anotherString):
+        # type: (String) -> bool
+        pass
+
+    def getBytes(self, *args):
+        # type: (*Any) -> Optional[object]
+        return array.array("b", self)
+
+    def getChars(self, srcBegin, srcEnd, dst, dstBegin):
+        # type: (int, int, object, int) -> None
+        pass
+
+    def getClass(self):
+        # type: () -> Class
+        pass
+
+    def hashCode(self):
+        # type: () -> int
+        return hash(self)
+
+    def indexOf(self, arg, fromIndex=None):
+        # type: (Union[int, String], Optional[int]) -> int
+        pass
+
+    def intern(self):
+        # type: () -> String
+        pass
+
+    def isBlank(self):
+        # type: () -> bool
+        pass
+
+    def isEmpty(self):
+        # type: () -> bool
+        pass
+
+    def lastIndexOf(self, arg, fromIndex=None):
+        # type: (Union[int, String], Optional[int]) -> int
+        pass
+
+    def length(self):
+        # type: () -> int
+        return len(self)
+
+    def lines(self):  # type: ignore[no-untyped-def]
+        pass
+
+    def matches(self, regex):
+        # type: (String) -> bool
+        pass
+
+    def notify(self):
+        # type: () -> None
+        pass
+
+    def notifyAll(self):
+        # type: () -> None
+        pass
+
+    def offsetByCodePoints(self, index, codePointOffset):
+        # type: (int, int) -> int
+        pass
+
+    def regionMatches(self, *args):
+        # type: (*Any) -> bool
+        pass
+
+    def repeat(self, count):
+        # type: (int) -> String
+        pass
+
+    def replaceAll(self, regex, replacement):
+        # type: (String, String) -> String
+        pass
+
+    def replaceFirst(self, regex, replacement):
+        # type: (String, String) -> String
+        pass
+
+    def startsWith(self, prefix, offset=0):
+        # type: (String, int) -> bool
+        return self.startswith(prefix, offset)
+
+    def stripLeading(self):
+        # type: () -> String
+        pass
+
+    def stripTrailing(self):
+        # type: () -> String
+        pass
+
+    def subSequence(self, start, end):
+        # type: (int, int) -> CharSequence
+        pass
+
+    def substring(self, beginIndex, endIndex=None):
+        # type: (int, Optional[int]) -> String
+        pass
+
+    def toCharArray(self):
+        # type: () -> object
+        return array.array("c", self)
+
+    def toLowerCase(self, locale=None):
+        # type: (Optional[Any]) -> String
+        print(locale)
+        return String(self.lower())
+
+    def toString(self):
+        # type: () -> unicode
+        return unicode(self)
+
+    def toUpperCase(self):
+        # type: () -> String
+        return String(self.upper())
+
+    @staticmethod
+    def valueOf(*args):
+        # type: (*Any) -> String
+        pass
+
+    def wait(self, timeoutMillis=0, nanos=0):
+        # type: (long, int) -> None
+        pass
+
+
 class StringBuffer(Object, CharSequence):
     def __init__(self, *args):
         # type: (Any) -> None
-        pass
+        super(StringBuffer, self).__init__()
+        print(args)
 
     def append(self, *args):
         # type: (Any) -> StringBuffer
@@ -334,7 +548,8 @@ class StringBuffer(Object, CharSequence):
 class StringBuilder(Object, CharSequence):
     def __init__(self, *args):
         # type: (Any) -> None
-        pass
+        super(StringBuilder, self).__init__()
+        print(args)
 
     def append(self, *args):
         # type: (Any) -> StringBuilder
@@ -381,7 +596,7 @@ class StringBuilder(Object, CharSequence):
         pass
 
     def indexOf(self, str_, fromIndex=0):
-        # type: (String, int) -> int
+        # type: (AnyStr, int) -> int
         pass
 
     def insert(self, *args):
@@ -389,7 +604,7 @@ class StringBuilder(Object, CharSequence):
         pass
 
     def lastIndexOf(self, str_, fromIndex=0):
-        # type: (String, int) -> int
+        # type: (AnyStr, int) -> int
         pass
 
     def length(self):
@@ -421,7 +636,7 @@ class StringBuilder(Object, CharSequence):
         pass
 
     def substring(self, start, end=-1):
-        # type: (int, int) -> String
+        # type: (int, int) -> AnyStr
         pass
 
     def trimToSize(self):
@@ -436,6 +651,7 @@ class Throwable(Object, builtins.Exception):
 
     def __init__(self, message=None, cause=None):
         # type: (Optional[str], Optional[Throwable]) -> None
+        super(Throwable, self).__init__()
         self._cause = cause
         self._message = message
         builtins.Exception.__init__(self, message)
@@ -491,7 +707,7 @@ class Throwable(Object, builtins.Exception):
         pass
 
     def toString(self):
-        # type: () -> String
+        # type: () -> AnyStr
         return "A short description of this throwable."
 
 
