@@ -34,22 +34,22 @@ __all__ = [
 import os.path
 from typing import Any, Dict, List, Optional, Type, Union
 
-from com.inductiveautomation.ignition.common import BasicDataset, Dataset
+from com.inductiveautomation.ignition.common import Dataset
 from com.inductiveautomation.ignition.common.script.builtin import DatasetUtilities
-from dev.thecesrom.helper.types import AnyStr
+from dev.thecesrom.helper.types import AnyNum, AnyStr
 from java.util import Date, Locale
 
-ColType = Union[Date, float, int, str, unicode]
+ColType = Union[AnyNum, AnyStr, Date]
 
 
 def addColumn(
-    dataset,  # type: BasicDataset
+    dataset,  # type: Dataset
     colIndex,  # type: int
     col,  # type: List[Any]
     colName,  # type: AnyStr
     colType,  # type: Type[ColType]
 ):
-    # type: (...) -> BasicDataset
+    # type: (...) -> Dataset
     """Takes a dataset and returns a new dataset with a new column added
     or inserted into it.
 
@@ -74,7 +74,7 @@ def addColumn(
         col: A Python sequence representing the data for the new column.
             Its length must equal the number of rows in the dataset.
         colName: The name of the column.
-        colType: The type of the of the column. The type can be a Python
+        colType: The type of the column. The type can be a Python
             builtin type, such as str, int, float, or a Java class, such
             as java.util.Date.
 
@@ -82,11 +82,11 @@ def addColumn(
         A new dataset with the new column inserted or appended.
     """
     print(dataset, colIndex, col, colName, colType)
-    return BasicDataset()
+    return Dataset()
 
 
 def addRow(dataset, rowIndex, row):
-    # type: (BasicDataset, int, List[Any]) -> BasicDataset
+    # type: (Dataset, int, List[Any]) -> Dataset
     """Takes a dataset and returns a new dataset with a new row added or
     inserted into it.
 
@@ -115,11 +115,11 @@ def addRow(dataset, rowIndex, row):
         A new dataset with the new row inserted or appended.
     """
     print(dataset, rowIndex, row)
-    return BasicDataset()
+    return Dataset()
 
 
 def addRows(dataset, rowIndex, rows):
-    # type: (BasicDataset, int, List[List[Any]]) -> BasicDataset
+    # type: (Dataset, int, List[List[Any]]) -> Dataset
     """Takes a dataset and returns a new dataset with a new row added or
     inserted into it.
 
@@ -149,11 +149,11 @@ def addRows(dataset, rowIndex, rows):
         A new dataset with the new row inserted or appended.
     """
     print(dataset, rowIndex, rows)
-    return BasicDataset()
+    return Dataset()
 
 
 def appendDataset(dataset1, dataset2):
-    # type: (BasicDataset, BasicDataset) -> BasicDataset
+    # type: (Dataset, Dataset) -> Dataset
     """Takes two different datasets and returns a new dataset with the
     second dataset appended to the first.
 
@@ -170,11 +170,11 @@ def appendDataset(dataset1, dataset2):
         datasets.
     """
     print(dataset1, dataset2)
-    return BasicDataset()
+    return Dataset()
 
 
 def clearDataset(dataset):
-    # type: (BasicDataset) -> BasicDataset
+    # type: (Dataset) -> Dataset
     """Takes a dataset and returns a new dataset with all of the same
     column names, but all of the rows deleted.
 
@@ -191,11 +191,11 @@ def clearDataset(dataset):
         A new dataset with no data.
     """
     print(dataset)
-    return BasicDataset()
+    return Dataset()
 
 
 def dataSetToHTML(showHeaders, dataset, title):
-    # type: (bool, BasicDataset, AnyStr) -> AnyStr
+    # type: (bool, Dataset, AnyStr) -> AnyStr
     """Formats the contents of a dataset as an HTML page, returning the
     results as a string.
 
@@ -215,7 +215,7 @@ def dataSetToHTML(showHeaders, dataset, title):
 
 
 def deleteRow(dataset, rowIndex):
-    # type: (BasicDataset, int) -> BasicDataset
+    # type: (Dataset, int) -> Dataset
     """Takes a dataset and returns a new dataset with a row removed.
 
     Note:
@@ -242,11 +242,11 @@ def deleteRow(dataset, rowIndex):
     if rowIndex < 0:
         raise IndexError("Error")
 
-    return BasicDataset()
+    return Dataset()
 
 
 def deleteRows(dataset, rowIndices):
-    # type: (BasicDataset, List[int]) -> BasicDataset
+    # type: (Dataset, List[int]) -> Dataset
     """Takes a dataset and returns a new dataset with one or more rows
     removed.
 
@@ -274,11 +274,11 @@ def deleteRows(dataset, rowIndices):
     if -1 in rowIndices:
         raise IndexError("Error")
 
-    return BasicDataset()
+    return Dataset()
 
 
 def exportCSV(filename, showHeaders, dataset):
-    # type: (AnyStr, bool, BasicDataset) -> AnyStr
+    # type: (AnyStr, bool, Dataset) -> AnyStr
     """Exports the contents of a dataset as a CSV file, prompting the
     user to save the file to disk.
 
@@ -299,8 +299,13 @@ def exportCSV(filename, showHeaders, dataset):
     return os.path.expanduser("~")
 
 
-def exportExcel(filename, showHeaders, dataset, nullsEmpty=False):
-    # type: (AnyStr, bool, List[BasicDataset], bool) -> AnyStr
+def exportExcel(
+    filename,  # type: AnyStr
+    showHeaders,  # type: bool
+    dataset,  # type: Union[Dataset, List[Dataset]]
+    nullsEmpty=False,  # type: bool
+):
+    # type: (...) -> AnyStr
     """Exports the contents of a dataset as an Excel spreadsheet,
     prompting the user to save the file to disk.
 
@@ -313,8 +318,9 @@ def exportExcel(filename, showHeaders, dataset, nullsEmpty=False):
         filename: A suggested filename to save as.
         showHeaders: If True, the spreadsheet will include a header
             row.
-        dataset: A sequence of datasets, one for each sheet in the
-            resulting workbook.
+        dataset: Either a single dataset, or a list of datasets. When
+            passing a list, each element represents a single sheet in
+            the resulting workbook.
         nullsEmpty: If True, the spreadsheet will leave cells with NULL
             values empty, instead of allowing Excel to provide a default
             value like 0. Defaults to False. Optional.
@@ -328,7 +334,7 @@ def exportExcel(filename, showHeaders, dataset, nullsEmpty=False):
 
 
 def exportHTML(filename, showHeaders, dataset, title):
-    # type: (AnyStr, bool, BasicDataset, AnyStr) -> AnyStr
+    # type: (AnyStr, bool, Dataset, AnyStr) -> AnyStr
     """Exports the contents of a dataset to an HTML page.
 
     Prompts the user to save the file to disk.
@@ -349,10 +355,10 @@ def exportHTML(filename, showHeaders, dataset, title):
 
 
 def filterColumns(
-    dataset,  # type: BasicDataset
+    dataset,  # type: Dataset
     columns,  # type: Union[List[AnyStr], List[int]]
 ):
-    # type: (...) -> BasicDataset
+    # type: (...) -> Dataset
     """Takes a dataset and returns a view of the dataset containing only
     the columns found within the given list of columns.
 
@@ -372,11 +378,11 @@ def filterColumns(
         A new dataset containing the filtered columns.
     """
     print(dataset, columns)
-    return BasicDataset()
+    return Dataset()
 
 
 def formatDates(dataset, dateFormat, locale=Locale.ENGLISH):
-    # type: (BasicDataset, AnyStr, Optional[Locale]) -> BasicDataset
+    # type: (Dataset, AnyStr, Optional[Locale]) -> Dataset
     """Returns a new dataset with Date columns as strings formatted
     according to the dateFormat specified.
 
@@ -398,11 +404,11 @@ def formatDates(dataset, dateFormat, locale=Locale.ENGLISH):
         A new dataset, containing the formatted dates.
     """
     print(dataset, dateFormat, locale)
-    return BasicDataset()
+    return Dataset()
 
 
 def fromCSV(csv):
-    # type: (AnyStr) -> BasicDataset
+    # type: (AnyStr) -> Dataset
     """Converts a dataset stored in a CSV formatted string to a dataset
     that can be immediately assignable to a dataset property in your
     project.
@@ -418,11 +424,11 @@ def fromCSV(csv):
         A new dataset.
     """
     print(csv)
-    return BasicDataset()
+    return Dataset()
 
 
 def getColumnHeaders(dataset):
-    # type: (BasicDataset) -> List[AnyStr]
+    # type: (Dataset) -> List[AnyStr]
     """Takes in a dataset and returns the headers as a python list.
 
     Args:
@@ -435,8 +441,8 @@ def getColumnHeaders(dataset):
     return ["column1", "column2"]
 
 
-def setValue(dataset, rowIndex, columnName, value):
-    # type: (BasicDataset, int, AnyStr, Any) -> BasicDataset
+def setValue(dataset, rowIndex, columnNameOrIndex, value):
+    # type: (Dataset, int, Union[AnyStr, int], Any) -> Dataset
     """Takes a dataset and returns a new dataset with a one value
     altered.
 
@@ -452,23 +458,25 @@ def setValue(dataset, rowIndex, columnName, value):
             dataset.
         rowIndex: The index of the row to set the value at (starting at
             0).
-        columnName: The name of the column to set the value at. Case
-            insensitive.
+        columnNameOrIndex: The name of the column to set the value at,
+            or the index of the column to set the value at (starting at
+            0).
         value: The new value for the specified row/column.
 
     Returns:
          A new dataset, with the new value set at the given location.
     """
-    print(dataset, rowIndex, columnName, value)
-    return BasicDataset()
+    print(dataset, rowIndex, columnNameOrIndex, value)
+    return Dataset()
 
 
 def sort(
-    dataset,  # type: BasicDataset
+    dataset,  # type: Dataset
     keyColumn,  # type: Union[AnyStr, int]
     ascending=True,  # type: bool
+    naturalOrdering=True,  # type: bool
 ):
-    # type: (...) -> BasicDataset
+    # type: (...) -> Dataset
     """Takes a dataset and returns a sorted version of dataset.
 
     The sort order is determined by a single column. This works on
@@ -488,16 +496,20 @@ def sort(
         keyColumn: The index or column name to sort on.
         ascending: True for ascending order, False for descending order.
             If omitted, ascending order will be used. Optional.
+        naturalOrdering: True for natural ordering, False for
+            alphabetical ordering. Ignored if the sort column is a
+            directly sortable data type. If omitted, defaults to True
+            (natural ordering). Optional.
 
     Returns:
         A new sorted dataset.
     """
-    print(dataset, keyColumn, ascending)
-    return BasicDataset()
+    print(dataset, keyColumn, ascending, naturalOrdering)
+    return Dataset()
 
 
 def toCSV(
-    dataset,  # type: BasicDataset
+    dataset,  # type: Dataset
     showHeaders=True,  # type: bool
     forExport=False,  # type: bool
     localized=False,  # type: bool
@@ -529,7 +541,7 @@ def toCSV(
 
 
 def toDataSet(*args):
-    # type: (*Any) -> BasicDataset
+    # type: (*Any) -> Dataset
     """This function is used to convert PyDataSets to DataSets, and to
     create new datasets from raw Python lists.
 
@@ -545,12 +557,12 @@ def toDataSet(*args):
         The newly created dataset.
     """
     print(args)
-    return BasicDataset()
+    return Dataset()
 
 
 def toExcel(
     showHeaders,  # type: bool
-    dataset,  # type: List[BasicDataset]
+    dataset,  # type: List[Dataset]
     nullsEmpty=False,  # type: bool
     sheetNames=None,  # type: Optional[List[AnyStr]]
 ):
@@ -599,7 +611,7 @@ def toPyDataSet(dataset):
 
 
 def updateRow(dataset, rowIndex, changes):
-    # type: (BasicDataset, int, Dict[AnyStr, Any]) -> BasicDataset
+    # type: (Dataset, int, Dict[AnyStr, Any]) -> Dataset
     """Takes a dataset and returns a new dataset with a one row altered.
 
     To alter the row, this function takes a Python dictionary to
@@ -626,4 +638,4 @@ def updateRow(dataset, rowIndex, changes):
          according to the values in the dictionary.
     """
     print(dataset, rowIndex, changes)
-    return BasicDataset()
+    return Dataset()
