@@ -708,8 +708,8 @@ def runSFPrepUpdate(query, args, datasources):
 
 def runSFUpdateQuery(query, datasources):
     # type: (AnyStr, List[AnyStr]) -> bool
-    """Runs a query through the store and forward system and to
-    multiple datasources at the same time.
+    """Runs a query through the store and forward system and to multiple
+    datasources at the same time.
 
     Args:
         query: A query (typically an UPDATE, INSERT, or DELETE) to run.
