@@ -88,6 +88,9 @@ SSL_FLAG = 64
 WEBSTART_FLAG = 8
 
 
+globals = {}  # type: Dict[AnyStr, Any]
+
+
 def audit(
     action=None,  # type: Optional[AnyStr]
     actionValue=None,  # type: Optional[AnyStr]
@@ -181,8 +184,8 @@ def exit(force=False):
 
 def getAvailableLocales():
     # type: () -> List[AnyStr]
-    """Returns a collection of strings representing the Locales added
-    to the Translation Manager, such as 'en' for English.
+    """Returns a collection of strings representing the Locales added to
+    the Translation Manager, such as 'en' for English.
 
     Returns:
         A collection of strings representing the Locales added to the
@@ -220,8 +223,8 @@ def getClientId():
 
 def getConnectTimeout():
     # type: () -> int
-    """Returns the connect timeout in milliseconds for all
-    Client-to-Gateway communication.
+    """Returns the connect timeout in milliseconds for all Client-to-
+    Gateway communication.
 
     This is the maximum amount of time that communication operations to
     the Gateway will be given to connect. The default is 10,000 ms (10
@@ -323,7 +326,7 @@ def getGlobals():
     Returns:
         The global namespace, as a dictionary.
     """
-    return {}
+    return globals
 
 
 def getInactivitySeconds():
@@ -435,8 +438,8 @@ def getProperty(propertyName):
 
 def getReadTimeout():
     # type: () -> int
-    """Returns the read timeout in milliseconds for all
-    Client-to-Gateway communication.
+    """Returns the read timeout in milliseconds for all Client-to-
+    Gateway communication.
 
     This is the maximum amount of time allowed for a communication
     operation to complete. The default is 60,000 ms (1 minute).
@@ -484,7 +487,7 @@ def getSystemFlags():
     currently active.
 
     Examples:
-        A full screen client launched from the gateway webpage with no
+        A full-screen client launched from the gateway webpage with no
         SSL will have a value of 44 (Fullscreen flag + Webstart Flag +
         Client Flag).
 
@@ -549,8 +552,8 @@ def invokeAsynchronous(
 def invokeLater(function, delay=0):
     # type: (Callable[..., Any], int) -> None
     """Invokes (calls) the given Python function object after all of the
-    currently processing and pending events are done being processed,
-    or after a specified delay.
+    currently processing and pending events are done being processed, or
+    after a specified delay.
 
     The function will be executed on the GUI, or event dispatch, thread.
     This is useful for events like propertyChange events, where the
@@ -698,7 +701,7 @@ def retarget(
     project,  # type: AnyStr
     addresses=None,  # type: Optional[Union[AnyStr, List[AnyStr]]]
     params=None,  # type: Optional[Dict[AnyStr, Any]]
-    windows=None,  # type: Optional[AnyStr]
+    windows=None,  # type: Optional[List[AnyStr]]
 ):
     # type: (...) -> None
     """This function allows you to programmatically 'retarget' the
